@@ -1,25 +1,8 @@
 //
 //   Copyright 2014 DreamWorks Animation LLC.
 //
-//   Licensed under the Apache License, Version 2.0 (the "Apache License")
-//   with the following modification; you may not use this file except in
-//   compliance with the Apache License and the following modification to it:
-//   Section 6. Trademarks. is deleted and replaced with:
-//
-//   6. Trademarks. This License does not grant permission to use the trade
-//      names, trademarks, service marks, or product names of the Licensor
-//      and its affiliates, except as required to comply with Section 4(c) of
-//      the License and to reproduce the content of the NOTICE file.
-//
-//   You may obtain a copy of the Apache License at
-//
-//       http://www.apache.org/licenses/LICENSE-2.0
-//
-//   Unless required by applicable law or agreed to in writing, software
-//   distributed under the Apache License with the above modification is
-//   distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-//   KIND, either express or implied. See the Apache License for the specific
-//   language governing permissions and limitations under the Apache License.
+//   Licensed under the terms set forth in the LICENSE.txt file available at
+//   https://opensubdiv.org/license.
 //
 #ifndef OPENSUBDIV3_SDC_CATMARK_SCHEME_H
 #define OPENSUBDIV3_SDC_CATMARK_SCHEME_H
@@ -121,7 +104,7 @@ Scheme<SCHEME_CATMARK>::assignSmoothMaskForEdge(EDGE const& edge, MASK& mask) co
         //
         //  This mimics the implementation in Hbr in terms of order of operations.
         //
-        const Weight CATMARK_SMOOTH_TRI_EDGE_WEIGHT = 0.470f;
+        const Weight CATMARK_SMOOTH_TRI_EDGE_WEIGHT = (Weight) 0.470;
 
         Weight f0Weight = face0IsTri ? CATMARK_SMOOTH_TRI_EDGE_WEIGHT : 0.25f;
         Weight f1Weight = face1IsTri ? CATMARK_SMOOTH_TRI_EDGE_WEIGHT : 0.25f;
@@ -230,8 +213,8 @@ Scheme<SCHEME_CATMARK>::assignCreaseLimitMask(VERTEX const& vertex, MASK& posMas
     posMask.SetNumFaceWeights(0);
     posMask.SetFaceWeightsForFaceCenters(false);
 
-    Weight vWeight = 2.0f / 3.0f;
-    Weight eWeight = 1.0f / 6.0f;
+    Weight vWeight = (Weight)(2.0 / 3.0);
+    Weight eWeight = (Weight)(1.0 / 6.0);
 
     posMask.VertexWeight(0) = vWeight;
     for (int i = 0; i < valence; ++i) {
@@ -261,9 +244,9 @@ Scheme<SCHEME_CATMARK>::assignSmoothLimitMask(VERTEX const& vertex, MASK& posMas
 
     //  Specialize for the regular case:
     if (valence == 4) {
-        Weight fWeight = 1.0f / 36.0f;
-        Weight eWeight = 1.0f /  9.0f;
-        Weight vWeight = 4.0f /  9.0f;
+        Weight fWeight = (Weight)(1.0 / 36.0);
+        Weight eWeight = (Weight)(1.0 /  9.0);
+        Weight vWeight = (Weight)(4.0 /  9.0);
 
         posMask.VertexWeight(0) = vWeight;
 
@@ -277,9 +260,11 @@ Scheme<SCHEME_CATMARK>::assignSmoothLimitMask(VERTEX const& vertex, MASK& posMas
         posMask.FaceWeight(2) = fWeight;
         posMask.FaceWeight(3) = fWeight;
     } else {
-        Weight fWeight = 1.0f / (Weight)(valence * (valence + 5.0f));
+        Weight Valence = (Weight) valence;
+
+        Weight fWeight = 1.0f / (Valence * (Valence + 5.0f));
         Weight eWeight = 4.0f * fWeight;
-        Weight vWeight = (Weight)(1.0f - valence * (eWeight + fWeight));
+        Weight vWeight = 1.0f - Valence * (eWeight + fWeight);
 
         posMask.VertexWeight(0) = vWeight;
         for (int i = 0; i < valence; ++i) {
@@ -362,7 +347,7 @@ Scheme<SCHEME_CATMARK>::assignCreaseLimitTangentMasks(VERTEX const& vertex,
 
     //
     //  Second, the tangent across the interior faces:
-    //      Note this is ambigous for an interior vertex.  We currently return
+    //      Note this is ambiguous for an interior vertex.  We currently return
     //  the tangent for the surface in the counter-clockwise span between the
     //  leading and trailing edges that form the crease.  Given the expected
     //  computation of a surface normal as Tan1 X Tan2, this tangent should be
@@ -385,14 +370,14 @@ Scheme<SCHEME_CATMARK>::assignCreaseLimitTangentMasks(VERTEX const& vertex,
     if (interiorEdgeCount == 1) {
         //  The regular case -- uniform B-spline cross-tangent:
 
-        tan2Mask.VertexWeight(0) = -4.0f / 6.0f;
+        tan2Mask.VertexWeight(0) = (Weight)(-4.0 / 6.0);
 
-        tan2Mask.EdgeWeight(creaseEnds[0])     = -1.0f / 6.0f;
-        tan2Mask.EdgeWeight(creaseEnds[0] + 1) =  4.0f / 6.0f;
-        tan2Mask.EdgeWeight(creaseEnds[1])     = -1.0f / 6.0f;
+        tan2Mask.EdgeWeight(creaseEnds[0])     = (Weight)(-1.0 / 6.0);
+        tan2Mask.EdgeWeight(creaseEnds[0] + 1) = (Weight)( 4.0 / 6.0);
+        tan2Mask.EdgeWeight(creaseEnds[1])     = (Weight)(-1.0 / 6.0);
 
-        tan2Mask.FaceWeight(creaseEnds[0])     = 1.0f / 6.0f;
-        tan2Mask.FaceWeight(creaseEnds[0] + 1) = 1.0f / 6.0f;
+        tan2Mask.FaceWeight(creaseEnds[0])     = (Weight)(1.0 / 6.0);
+        tan2Mask.FaceWeight(creaseEnds[0] + 1) = (Weight)(1.0 / 6.0);
     } else if (interiorEdgeCount > 1) {
         //  The irregular case -- formulae from Biermann et al:
 
@@ -483,7 +468,7 @@ Scheme<SCHEME_CATMARK>::assignSmoothLimitTangentMasks(VERTEX const& vertex,
         double cosTheta     = std::cos(theta);
         double cosHalfTheta = std::cos(theta * 0.5f);
 
-        double lambda = (5.0f / 16.0f) + (1.0f / 16.0f) *
+        double lambda = (5.0 / 16.0) + (1.0 / 16.0) *
                 (cosTheta + cosHalfTheta * std::sqrt(2.0f * (9.0f + cosTheta)));
 
         double edgeWeightScale = 4.0f;
